@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bdevicecombobox.h 421129 2005-06-02 09:33:12Z trueg $
+ * $Id: k3bdevicecombobox.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,14 +18,20 @@
 #define _K3B_DEVICE_COMBO_BOX_H_
 
 #include <kcombobox.h>
-
+#include "k3b_export.h"
 
 namespace K3bDevice {
   class Device;
+  class DeviceManager;
 }
 
 
-class K3bDeviceComboBox : public KComboBox
+/**
+ * A combobox to select a K3b device.
+ *
+ * It automatically removes devices that are removed from the system.
+ */
+class LIBK3B_EXPORT K3bDeviceComboBox : public KComboBox
 {
   Q_OBJECT
 
@@ -41,11 +47,17 @@ class K3bDeviceComboBox : public KComboBox
  public slots:
   void addDevice( K3bDevice::Device* );
   void addDevices( const QPtrList<K3bDevice::Device>& );
+  /**
+   * Clears the device combo and tries to keep the current selection
+   */
+  void refreshDevices( const QPtrList<K3bDevice::Device>& );
+  void removeDevice( K3bDevice::Device* );
   void setSelectedDevice( K3bDevice::Device* );
   void clear();
 
  private slots:
   void slotActivated( int );
+  void slotDeviceManagerChanged( K3bDevice::DeviceManager* dm );
 
  private:
   class Private;
