@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bsystemproblemdialog.cpp 627607 2007-01-27 11:21:19Z trueg $
+ * $Id: k3bsystemproblemdialog.cpp 655079 2007-04-17 17:17:08Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -222,6 +222,7 @@ void K3bSystemProblemDialog::checkSystem( QWidget* parent,
 					     QString::null,
 					     true ) );
       }
+#ifdef CDRECORD_SUID_ROOT_CHECK
       else if( !k3bcore->externalBinManager()->binObject( "cdrecord" )->hasFeature( "suidroot" ) && getuid() != 0 ) // not root
 	problems.append( K3bSystemProblem( K3bSystemProblem::CRITICAL,
 					   i18n("%1 will be run without root privileges").arg("cdrecord"),
@@ -234,6 +235,7 @@ void K3bSystemProblemDialog::checkSystem( QWidget* parent,
 						"true when using SuSE's resmgr."),
 					   QString::null,
 					   true ) );
+#endif // CDRECORD_SUID_ROOT_CHECK
 #endif
     }
 
@@ -246,6 +248,7 @@ void K3bSystemProblemDialog::checkSystem( QWidget* parent,
     }
     else {
 #ifdef Q_OS_LINUX
+#ifdef CDRECORD_SUID_ROOT_CHECK
       if( !k3bcore->externalBinManager()->binObject( "cdrdao" )->hasFeature( "suidroot" ) && getuid() != 0 )
 	problems.append( K3bSystemProblem( K3bSystemProblem::CRITICAL,
 					   i18n("%1 will be run without root privileges").arg("cdrdao"),
@@ -254,6 +257,7 @@ void K3bSystemProblemDialog::checkSystem( QWidget* parent,
 						"overall stability of the burning process."),
 					   QString::null,
 					   true ) );
+#endif // CDRECORD_SUID_ROOT_CHECK
 #endif
     }
   }
